<?php
/**
 * Basic database structure file.
 *
 * @copyright YetiForce S.A.
 * @license   YetiForce Public License 7.0 (licenses/LicenseEN.txt or yetiforce.com)
 * @author    Radosław Skrzypczak <r.skrzypczak@yetiforce.com>
 */

namespace Importers;

/**
 * Basic database structure class.
 */
class Base extends \App\Db\Importers\Base
{
    /** {@inheritdoc} */
    public $dbType = 'base';

    /**
     * Scheme.
     *
     * @return void
     */
    public function scheme(): void
    {
        $this->tables = [
            'a_#__map_coordinates_driver_config' => [
                'columns' => [
                    'id' => $this->primaryKeyUnsigned(10),
                    'driver' => $this->stringType(100)->notNull(),
                    'api_key' => $this->stringType(500),
                    'active' => $this->smallInteger(1)->notNull()->defaultValue(0),
                ],
                'columns_mysql' => [
                    'active' => $this->tinyInteger(1)->notNull()->defaultValue(0),
                ],
                'engine' => 'InnoDB',
                'charset' => 'utf8'
            ],
            'a_#__map_routing_driver_config' => [
                'columns' => [
                    'id' => $this->primaryKeyUnsigned(10),
                    'driver' => $this->stringType(100)->notNull(),
                    'api_key' => $this->stringType(500),
                    'params' => $this->text(),
                    'active' => $this->smallInteger(1)->notNull()->defaultValue(0),
                ],
                'columns_mysql' => [
                    'active' => $this->tinyInteger(1)->notNull()->defaultValue(0),
                ],
                'engine' => 'InnoDB',
                'charset' => 'utf8'
            ],
            'a_#__map_tile_layer_driver_config' => [
                'columns' => [
                    'id' => $this->primaryKeyUnsigned(10),
                    'driver' => $this->stringType(100)->notNull(),
                    'api_key' => $this->stringType(500),
                    'active' => $this->smallInteger(1)->notNull()->defaultValue(0),
                ],
                'columns_mysql' => [
                    'active' => $this->tinyInteger(1)->notNull()->defaultValue(0),
                ],
                'engine' => 'InnoDB',
                'charset' => 'utf8'
            ],
            'a_#__smsnotifier_servers' => [
                'columns' => [
                    'default' => $this->smallInteger(1)->defaultValue(0),
                ],
                'columns_mysql' => [
                    'default' => $this->tinyInteger(1)->defaultValue(0),
                ],
                'engine' => 'InnoDB',
                'charset' => 'utf8'
            ],
            'a_#__taxes_global' => [
                'columns' => [
                    'show_name' => $this->smallInteger(1)->notNull()->defaultValue(0),
                ],
                'columns_mysql' => [
                    'show_name' => $this->tinyInteger(1)->notNull()->defaultValue(0),
                ],
                'engine' => 'InnoDB',
                'charset' => 'utf8'
            ],
            's_#__auto_assign' => [
                'columns' => [
                    'working_hours' => $this->smallInteger(1)->defaultValue(0),
                ],
                'columns_mysql' => [
                    'working_hours' => $this->tinyInteger(1)->defaultValue(0),
                ],
                'engine' => 'InnoDB',
                'charset' => 'utf8'
            ],
            's_#__calendar_sources' => [
                'columns' => [
                    'id' => $this->primaryKeyUnsigned(10),
                    'label' => $this->stringType(100),
                    'base_module' => $this->smallInteger(5)->notNull(),
                    'target_module' => $this->smallInteger(5)->notNull(),
                    'user_id' => $this->integer(10)->notNull(),
                    'type' => $this->smallInteger(1)->unsigned()->notNull()->defaultValue(1),
                    'public' => $this->smallInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'include_filters' => $this->smallInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'color' => $this->stringType(10),
                    'custom_view' => $this->integer(10)->unsigned()->notNull()->defaultValue(0),
                    'field_label' => $this->integer(10)->notNull()->defaultValue(0),
                    'fieldid_a_date' => $this->integer(10)->notNull(),
                    'fieldid_a_time' => $this->integer(10)->notNull()->defaultValue(0),
                    'fieldid_b_date' => $this->integer(10)->notNull()->defaultValue(0),
                    'fieldid_b_time' => $this->integer(10)->notNull()->defaultValue(0),
                ],
                'columns_mysql' => [
                    'type' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(1),
                    'public' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'include_filters' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(0),
                ],
                'index' => [
                    ['base_module', 'base_module'],
                    ['target_module', 'target_module'],
                ],
                'engine' => 'InnoDB',
                'charset' => 'utf8'
            ],
            's_#__mail_account' => [
                'columns' => [
                    'id' => $this->primaryKeyUnsigned(10),
                    'name' => $this->stringType(),
                    'login' => $this->stringType(),
                    'password' => $this->text(),
                    'refresh_token' => $this->text(),
                    'mail_server_id' => $this->integer(10)->unsigned()->notNull(),
                    'status' => $this->stringType()->notNull(),
                    'logs' => $this->text(),
                    'expire_time' => $this->dateTime(),
                    'scanner_actions' => $this->text(),
                    'scanner_fields' => $this->text(),
                    'domain_exceptions' => $this->text(),
                    'email_exceptions' => $this->text(),
                    'folders' => $this->text(),
                    'last_login' => $this->dateTime(),
                    'owner_id' => $this->integer()->notNull(),
                    'private' => $this->smallInteger(1)->defaultValue(1),
                ],
                'columns_mysql' => [
                    'private' => $this->tinyInteger(1)->defaultValue(1),
                ],
                'index' => [
                    ['s_yf_mail_account_mail_server_id_fk', 'mail_server_id'],
                ],
                'engine' => 'InnoDB',
                'charset' => 'utf8'
            ],
            's_#__mail_queue' => [
                'columns' => [
                    'callback' => $this->stringType(),
                ],
                'columns_mysql' => [
                    'status' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'priority' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(1),
                ],
                'engine' => 'InnoDB',
                'charset' => 'utf8'
            ],
            's_#__mail_servers' => [
                'columns' => [
                    'id' => $this->primaryKeyUnsigned(10),
                    'status' => $this->smallInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'name' => $this->stringType(50)->notNull(),
                    'auth_method' => $this->stringType(50)->notNull(),
                    'imap_encrypt' => $this->stringType(5)->notNull()->defaultValue(''),
                    'imap_host' => $this->stringType()->notNull(),
                    'imap_port' => $this->smallInteger(5)->unsigned()->notNull(),
                    'smtp_encrypt' => $this->stringType(5)->notNull()->defaultValue(''),
                    'smtp_host' => $this->stringType()->notNull(),
                    'smtp_port' => $this->smallInteger(5)->unsigned()->notNull(),
                    'oauth_provider' => $this->stringType(50)->defaultValue(''),
                    'client_id' => $this->stringType()->defaultValue(''),
                    'client_secret' => $this->stringType(500)->defaultValue(''),
                    'redirect_uri_id' => $this->integer(10)->unsigned()->defaultValue(0),
                    'validate_cert' => $this->smallInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'spellcheck' => $this->smallInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'ip_check' => $this->smallInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'visible' => $this->smallInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'identities_level' => $this->stringType(),
                ],
                'columns_mysql' => [
                    'status' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'validate_cert' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'spellcheck' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'ip_check' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'visible' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(0),
                ],
                'index' => [
                    ['name', 'name', true],
                ],
                'engine' => 'InnoDB',
                'charset' => 'utf8'
            ],
            's_#__mail_signature' => [
                'columns' => [
                    'id' => $this->primaryKeyUnsigned(10),
                    'name' => $this->stringType()->notNull(),
                    'status' => $this->smallInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'default' => $this->smallInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'body' => $this->mediumText(),
                ],
                'columns_mysql' => [
                    'status' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'default' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(0),
                ],
                'index' => [
                    ['status', 'status'],
                ],
                'engine' => 'InnoDB',
                'charset' => 'utf8'
            ],
            's_#__mail_smtp' => [
                'columns' => [
                    'imap_host' => ['type' => $this->stringType(), 'renameFrom' => 'smtp_host'],
                    'imap_port' => ['type' => $this->smallInteger(), 'renameFrom' => 'smtp_port'],
                    'imap_username' => ['type' => $this->stringType(), 'renameFrom' => 'smtp_username'],
                    'imap_password' => ['type' => $this->text(), 'renameFrom' => 'smtp_password'],
                    'imap_folder' => ['type' => $this->stringType(50), 'renameFrom' => 'smtp_folder'],
                    'imap_validate_cert' => ['type' => $this->smallInteger(1)->defaultValue(0), 'renameFrom' => 'smtp_validate_cert'],
                    'auth_method' => $this->stringType(50)->notNull(),
                    'oauth_provider' => $this->stringType(50),
                    'client_id' => $this->stringType(),
                    'client_secret' => $this->stringType(500),
                    'redirect_uri_id' => $this->integer(10)->unsigned(),
                    'refresh_token' => $this->text(),
                ],
                'columns_mysql' => [
                    'imap_validate_cert' => ['type' => $this->tinyInteger(1)->defaultValue(0), 'renameFrom' => 'smtp_validate_cert'],
                ],
                'engine' => 'InnoDB',
                'charset' => 'utf8'
            ],

            'i_#__comarch_servers' => [
                'columns' => [
                    'id' => $this->primaryKeyUnsigned(10),
                    'status' => $this->smallInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'type' => $this->smallInteger(1)->unsigned()->notNull()->defaultValue(1),
                    'name' => $this->stringType(50)->notNull(),
                    'url' => $this->stringType()->notNull(),
                    'user_name' => $this->stringType()->notNull(),
                    'password' => $this->stringType()->notNull(),
                    'connector' => $this->stringType(20)->notNull(),
                    'verify_ssl' => $this->smallInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'master' => $this->smallInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'log_all' => $this->smallInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'assigned_user_id' => $this->smallInteger(5)->unsigned()->notNull(),
                    'sync_accounts' => $this->smallInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'sync_products' => $this->smallInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'sync_invoices' => $this->smallInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'sync_cor_invoices' => $this->smallInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'sync_payments' => $this->smallInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'direction_accounts' => $this->smallInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'direction_products' => $this->smallInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'direction_invoices' => $this->smallInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'direction_cor_invoices' => $this->smallInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'direction_payments' => $this->smallInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'accounts_limit' => $this->smallInteger(5)->unsigned()->notNull()->defaultValue(1000),
                    'products_limit' => $this->smallInteger(5)->unsigned()->notNull()->defaultValue(1000),
                    'invoices_limit' => $this->smallInteger(5)->unsigned()->notNull()->defaultValue(1000),
                    'cor_invoices_limit' => $this->smallInteger(5)->unsigned()->notNull()->defaultValue(1000),
                ],
                'columns_mysql' => [
                    'status' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'type' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(1),
                    'verify_ssl' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'master' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'log_all' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'sync_accounts' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'sync_products' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'sync_invoices' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'sync_cor_invoices' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'sync_payments' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'direction_accounts' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'direction_products' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'direction_invoices' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'direction_cor_invoices' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'direction_payments' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(0),
                ],
                'index' => [
                    ['status', 'status'],
                    ['type', 'type'],
                ],
                'engine' => 'InnoDB',
                'charset' => 'utf8'
            ],
            'i_#__woocommerce_servers' => [
                'columns' => [
                    'id' => $this->primaryKeyUnsigned(10),
                    'status' => $this->smallInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'name' => $this->stringType(50)->notNull(),
                    'url' => $this->stringType()->notNull(),
                    'user_name' => $this->stringType()->notNull(),
                    'password' => $this->stringType()->notNull(),
                    'connector' => $this->stringType(20)->notNull(),
                    'verify_ssl' => $this->smallInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'master' => $this->smallInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'assigned_user_id' => $this->smallInteger(5)->unsigned()->notNull(),
                    'sync_currency' => $this->smallInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'sync_categories' => $this->smallInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'direction_categories' => $this->smallInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'sync_tags' => $this->smallInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'direction_tags' => $this->smallInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'sync_products' => $this->smallInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'direction_products' => $this->smallInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'sync_orders' => $this->smallInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'direction_orders' => $this->smallInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'shipping_service_id' => $this->integer(10)->unsigned()->notNull()->defaultValue(0),
                    'products_limit' => $this->smallInteger(5)->unsigned()->notNull()->defaultValue(1000),
                    'orders_limit' => $this->smallInteger(5)->unsigned()->notNull()->defaultValue(200),
                ],
                'columns_mysql' => [
                    'status' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'verify_ssl' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'master' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'sync_currency' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'sync_categories' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'direction_categories' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'sync_tags' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'direction_tags' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'sync_products' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'direction_products' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'sync_orders' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(0),
                    'direction_orders' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(0),
                ],
                'engine' => 'InnoDB',
                'charset' => 'utf8'
            ],
            'roundcube_users' => [
                'columns' => [
                    'crm_ma_id' => $this->integer(10)->defaultValue(0),
                ],
                'engine' => 'InnoDB',
                'charset' => 'utf8mb4'
            ],
            'u_#__mailscanner_folders' => [
                'columns' => [
                    'id' => $this->integer(10)->unsigned()->notNull(),
                    'name' => $this->stringType()->notNull(),
                    'uid' => $this->integer(1)->unsigned()->notNull()->defaultValue(0),
                ],
                'index' => [
                    ['u_yf_mailscanner_folders_user_id_name_idx', ['id', 'name'], true],
                ],
                'engine' => 'InnoDB',
                'charset' => 'utf8'
            ],
            'u_#__openstreetmap' => [
                'columns' => [
                    'type' => $this->stringType(50)->notNull(),
                    'lat' => $this->decimal('13,10')->notNull(),
                    'lon' => $this->decimal('13,10')->notNull(),
                ],
                'engine' => 'InnoDB',
                'charset' => 'utf8'
            ],
            'vtiger_callhistory' => [
                'index' => [
                    ['callhistorytype', 'callhistorytype'],
                    ['destination', 'destination'],
                    ['phonecallid', 'phonecallid'],
                    ['source', 'source'],
                    ['start_time', 'start_time'],
                    ['subscriberid', 'subscriberid'],
                    ['to_number', 'to_number'],
                ],
                'engine' => 'InnoDB',
                'charset' => 'utf8'
            ],
            'vtiger_callhistorytype' => [
                'columns' => [
                    'color' => $this->stringType(25),
                ],
                'engine' => 'InnoDB',
                'charset' => 'utf8'
            ],
            'vtiger_currency_info' => [
                'columns' => [
                    'conversion_rate' => $this->decimal('19,9'),
                ],
                'engine' => 'InnoDB',
                'charset' => 'utf8'
            ],
            'vtiger_ossmails_logs' => [
                'columns' => [
                    'info' => $this->stringType()->defaultValue(''),
                ],
                'engine' => 'InnoDB',
                'charset' => 'utf8'
            ],
            'vtiger_ossmailview' => [
                'columns' => [
                    'msgid' => ['type' => $this->stringType()->defaultValue(''), 'renameFrom' => 'uid'],
                    'uid' => ['type' => $this->integer(10)->unsigned(), 'renameFrom' => 'id'],
                ],
                'engine' => 'InnoDB',
                'charset' => 'utf8mb4'
            ],
            'vtiger_relatedlists' => [
                'columns' => [
                    'custom_view_orderby' => $this->smallInteger(1)->unsigned()->notNull()->defaultValue(0),
                ],
                'columns_mysql' => [
                    'custom_view_orderby' => $this->tinyInteger(1)->unsigned()->notNull()->defaultValue(0),
                ],
                'engine' => 'InnoDB',
                'charset' => 'utf8'
            ],
            'vtiger_smsnotifier' => [
                'columns' => [
                    'sms_provider_id' => $this->integer(10),
                ],
                'index' => [
                    ['vtiger_smsnotifier_sms_provider_id_idx', 'sms_provider_id'],
                ],
                'engine' => 'InnoDB',
                'charset' => 'utf8'
            ],
            'vtiger_users' => [
                'columns' => [
                    'internal_mailer' => $this->stringType(),
                    'user_pbx' => $this->smallInteger(5)->notNull()->defaultValue(-1),
                    'mail_popup' => $this->smallInteger(1)->defaultValue(1),
                ],
                'columns_mysql' => [
                    'mail_popup' => $this->tinyInteger(1)->defaultValue(1),
                ],
                'engine' => 'InnoDB',
                'charset' => 'utf8'
            ],
            'yetiforce_currencyupdate' => [
                'columns' => [
                    'exchange' => $this->decimal('19,9')->notNull(),
                ],
                'engine' => 'InnoDB',
                'charset' => 'utf8'
            ],
            'yetiforce_mail_config' => [
                'columns' => [
                    'sequence' => $this->smallInteger(5)->unsigned()->defaultValue(0),
                ],
                'engine' => 'InnoDB',
                'charset' => 'utf8'
            ],
            'l_#__mail' => [
                'columns' => [
                    'smtp_id' => $this->integer(10)->unsigned(),
                    'callback' => $this->stringType(),
                ],
                'engine' => 'InnoDB',
                'charset' => 'utf8mb4'
            ],
            'l_#__pbx' => [
                'columns' => [
                    'id' => $this->primaryKeyUnsigned(10),
                    'time' => $this->dateTime()->notNull(),
                    'error' => $this->smallInteger(1),
                    'driver' => $this->stringType(100),
                    'message' => $this->stringType(),
                    'params' => $this->text(),
                ],
                'columns_mysql' => [
                    'error' => $this->tinyInteger(1),
                ],
                'engine' => 'InnoDB',
                'charset' => 'utf8'
            ],
            'w_#__portal_session' => [
                'columns' => [
                    'last_method' => $this->stringType(),
                    'agent' => $this->stringType()->notNull(),
                ],
                'engine' => 'InnoDB',
                'charset' => 'utf8'
            ],
        ];
        $this->foreignKey = [
            ['fk_module_relations_entityname', 'a_#__module_reference', 'module_id', 'vtiger_entityname', 'tabid', 'CASCADE', null],
            // ['a_#__modules_packages_module_fk', 'a_#__modules_packages', 'module_id', 'vtiger_tab', 'tabid', 'CASCADE', null],
            // ['a_#__modules_packages_package_fk', 'a_#__modules_packages', 'package_id', 'a_#__module_package', 'id', 'CASCADE', null],
            ['s_#__calendar_sources_ibfk_1', 's_#__calendar_sources', 'base_module', 'vtiger_tab', 'tabid', 'CASCADE', null],
            ['s_#__calendar_sources_ibfk_2', 's_#__calendar_sources', 'target_module', 'vtiger_tab', 'tabid', 'CASCADE', null],
            ['s_#__mail_account_mail_server_id_fk', 's_#__mail_account', 'mail_server_id', 's_#__mail_servers', 'id', 'CASCADE', null],
            // ['roundcube_users_autologin_ibfk_1', 'roundcube_users_autologin', 'rcuser_id', 's_#__mail_account', 'id', 'CASCADE', null],
            ['u_#__mailscanner_folders_id_fk', 'u_#__mailscanner_folders', 'id', 's_#__mail_account', 'id', 'CASCADE', null],
        ];
    }
}
